@@ -21,6 +21,11 @@ Implementation Notes
 
 """
 
+try:
+    from typing import Optional
+except ImportError:
+    pass
+
 from adafruit_display_shapes.polygon import Polygon
 
 __version__ = "0.0.0-auto.0"
@@ -38,15 +43,22 @@ class Line(Polygon):
     :param color: The color of the line.
     """
 
-    def __init__(self, x0, y0, x1, y1, color):
+    def __init__(
+        self,
+        x0: int,
+        y0: int,
+        x1: int,
+        y1: int,
+        color: int,
+    ) -> None:
         super().__init__([(x0, y0), (x1, y1)], outline=color)
 
     @property
-    def color(self):
+    def color(self) -> Optional[int]:
         """The line color value. Can be a hex value for a color or
         ``None`` for no line color."""
         return self.outline
 
     @color.setter
-    def color(self, color):
+    def color(self, color: Optional[int]) -> None:
         self.outline = color
